# filepursuit

A python tool for scraping and downloading files from filepursuer

## Usage
Invoke the script as follows:

    filepursuit -s "SEARCH TERMS" -o "OUTPUT PATH" -t "TYPE"

where:

* SEARCH TERMS: Is a list of search terms between " "
* OUTPUT PATH: Is the path of the directory where you want to save the
downloaded files
* TYPE: Is the type of files you can search for (all, video, audio,
ebook, archive, mobile or a custom extension)


## TODO

* Change the scripts names: *scraper* also downloads the file, it doesnt
just scrape the site.
* Maybe add support for more direct download sites
* Improve the "interface".
* FilePursuit doesn't like when you flood the site with requests, so
it'll ask for a captcha. You'll see that the search returns zero results,
and won't know if it because there are no results, or if its because it
failed to parse the site.
